@@ -8,23 +8,30 @@
 # See https://github.com/nexB/python-inspector for support or download.
 # See https://aboutcode.org for more information about nexB OSS projects.
 #
+import os
+
 import packaging
 import pytest
+from commoncode.testcase import FileDrivenTesting
 from packaging.requirements import Requirement
 
 from _packagedcode import models
 from python_inspector.resolution import get_requirements_from_dependencies
 from python_inspector.resolution import get_resolved_dependencies
 from python_inspector.resolution import is_valid_version
+from python_inspector.resolution import parse_reqs_from_setup_py_insecurely
 from python_inspector.utils_pypi import PYPI_PUBLIC_REPO
 from python_inspector.utils_pypi import Environment
 
+setup_test_env = FileDrivenTesting()
+setup_test_env.test_data_dir = os.path.join(os.path.dirname(__file__), "data")
+
 
 @pytest.mark.online
 def test_get_resolved_dependencies_with_flask_and_python_310():
     req = Requirement("flask==2.1.2")
     req.is_requirement_resolved = True
-    results = get_resolved_dependencies(
+    _, plist = get_resolved_dependencies(
         requirements=[req],
         environment=Environment(
             python_version="310",
@@ -33,8 +40,7 @@ def test_get_resolved_dependencies_with_flask_and_python_310():
         repos=[PYPI_PUBLIC_REPO],
         as_tree=False,
     )
-    as_list = [p["package"] for p in results]
-    assert as_list == [
+    assert plist == [
         "pkg:pypi/click@8.1.3",
         "pkg:pypi/flask@2.1.2",
         "pkg:pypi/itsdangerous@2.1.2",
@@ -48,7 +54,7 @@ def test_get_resolved_dependencies_with_flask_and_python_310():
 def test_get_resolved_dependencies_with_flask_and_python_310_windows():
     req = Requirement("flask==2.1.2")
     req.is_requirement_resolved = True
-    results = get_resolved_dependencies(
+    _, plist = get_resolved_dependencies(
         requirements=[req],
         environment=Environment(
             python_version="310",
@@ -57,8 +63,7 @@ def test_get_resolved_dependencies_with_flask_and_python_310_windows():
         repos=[PYPI_PUBLIC_REPO],
         as_tree=False,
     )
-    as_list = [p["package"] for p in results]
-    assert as_list == [
+    assert plist == [
         "pkg:pypi/click@8.1.3",
         "pkg:pypi/colorama@0.4.5",
         "pkg:pypi/flask@2.1.2",
@@ -73,7 +78,7 @@ def test_get_resolved_dependencies_with_flask_and_python_310_windows():
 def test_get_resolved_dependencies_with_flask_and_python_36():
     req = Requirement("flask")
     req.is_requirement_resolved = False
-    results = get_resolved_dependencies(
+    _, plist = get_resolved_dependencies(
         requirements=[req],
         environment=Environment(
             python_version="36",
@@ -82,9 +87,8 @@ def test_get_resolved_dependencies_with_flask_and_python_36():
         repos=[PYPI_PUBLIC_REPO],
         as_tree=False,
     )
-    as_list = [p["package"] for p in results]
 
-    assert as_list == [
+    assert plist == [
         "pkg:pypi/click@8.0.4",
         "pkg:pypi/dataclasses@0.8",
         "pkg:pypi/flask@2.0.3",
@@ -102,7 +106,7 @@ def test_get_resolved_dependencies_with_flask_and_python_36():
 def test_get_resolved_dependencies_with_tilde_requirement_using_json_api():
     req = Requirement("flask~=2.1.2")
     req.is_requirement_resolved = False
-    results = get_resolved_dependencies(
+    _, plist = get_resolved_dependencies(
         requirements=[req],
         as_tree=False,
         environment=Environment(
@@ -110,8 +114,7 @@ def test_get_resolved_dependencies_with_tilde_requirement_using_json_api():
             operating_system="linux",
         ),
     )
-    as_list = [p["package"] for p in results]
-    assert as_list == [
+    assert plist == [
         "pkg:pypi/click@8.1.3",
         "pkg:pypi/flask@2.1.3",
         "pkg:pypi/importlib-metadata@4.12.0",
@@ -127,7 +130,7 @@ def test_get_resolved_dependencies_with_tilde_requirement_using_json_api():
 def test_without_supported_wheels():
     req = Requirement("autobahn==22.3.2")
     req.is_requirement_resolved = True
-    results = get_resolved_dependencies(
+    _, plist = get_resolved_dependencies(
         requirements=[req],
         as_tree=False,
         repos=[PYPI_PUBLIC_REPO],
@@ -136,16 +139,15 @@ def test_without_supported_wheels():
             operating_system="linux",
         ),
     )
-    as_list = [p["package"] for p in results]
 
-    assert as_list == [
+    assert plist == [
         "pkg:pypi/autobahn@22.3.2",
         "pkg:pypi/cffi@1.15.1",
-        "pkg:pypi/cryptography@37.0.4",
+        "pkg:pypi/cryptography@38.0.1",
         "pkg:pypi/hyperlink@21.0.0",
-        "pkg:pypi/idna@3.3",
+        "pkg:pypi/idna@3.4",
         "pkg:pypi/pycparser@2.21",
-        "pkg:pypi/setuptools@65.3.0",
+        "pkg:pypi/setuptools@65.4.0",
         "pkg:pypi/txaio@22.2.1",
     ]
 
@@ -218,3 +220,21 @@ def test_get_requirements_from_dependencies_with_editable_requirements():
     requirements = [str(r) for r in get_requirements_from_dependencies(dependencies)]
 
     assert requirements == []
+
+
+def test_setup_py_parsing_insecure():
+    setup_py_file = setup_test_env.get_test_loc("insecure-setup/setup.py")
+    reqs = [str(req) for req in list(parse_reqs_from_setup_py_insecurely(setup_py=setup_py_file))]
+    assert reqs == ["isodate", "pyparsing", "six"]
+
+
+def test_setup_py_parsing_insecure_testpkh():
+    setup_py_file = setup_test_env.get_test_loc("insecure-setup-2/setup.py")
+    reqs = [str(req) for req in list(parse_reqs_from_setup_py_insecurely(setup_py=setup_py_file))]
+    assert reqs == [
+        "CairoSVG<2.0.0,>=1.0.20",
+        "click>=5.0.0",
+        "invenio[auth,base,metadata]>=3.0.0",
+        "invenio-records==1.0.*,>=1.0.0",
+        "mock>=1.3.0",
+    ]
